@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2021 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,8 +84,8 @@ namespace sync {
   {
     try {
       NoteManager & manager(dynamic_cast<NoteManager&>(note_mgr()));
-      m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->signal_changed()
-        .connect(sigc::mem_fun(*this, &SyncManager::preferences_setting_changed));
+      m_gnote.preferences().signal_sync_selected_service_addin_changed.connect(sigc::mem_fun(*this, &SyncManager::update_sync_action));
+      m_gnote.preferences().signal_sync_autosync_timeout_changed.connect(sigc::mem_fun(*this, &SyncManager::update_sync_action));
       manager.signal_note_saved.connect(sigc::mem_fun(*this, &SyncManager::handle_note_saved_or_deleted));
       manager.signal_note_deleted.connect(sigc::mem_fun(*this, &SyncManager::handle_note_saved_or_deleted));
       manager.signal_note_buffer_changed.connect(sigc::mem_fun(*this, &SyncManager::handle_note_buffer_changed));
@@ -120,7 +120,8 @@ namespace sync {
 
     m_sync_ui = sync_ui;
     DBG_OUT("Creating synchronization thread");
-    m_sync_thread = Glib::Thread::create(sigc::mem_fun(*this, &SyncManager::synchronization_thread), false);
+    m_sync_thread = new std::thread([this] { synchronization_thread(); });
+    m_sync_thread->detach();
   }
 
 
@@ -417,20 +418,12 @@ namespace sync {
   }
 
 
-  void SyncManager::preferences_setting_changed(const Glib::ustring &)
-  {
-    // Update sync item based on configuration.
-    update_sync_action();
-  }
-
-
   void SyncManager::update_sync_action()
   {
-    Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC);
-    Glib::ustring sync_addin_id = settings->get_string(Preferences::SYNC_SELECTED_SERVICE_ADDIN);
+    Glib::ustring sync_addin_id = m_gnote.preferences().sync_selected_service_addin();
     m_gnote.action_manager().get_app_action("sync-notes")->set_enabled(sync_addin_id != "");
 
-    int timeoutPref = settings->get_int(Preferences::SYNC_AUTOSYNC_TIMEOUT);
+    int timeoutPref = m_gnote.preferences().sync_autosync_timeout();
     if(timeoutPref != m_autosync_timeout_pref_minutes) {
       m_autosync_timeout_pref_minutes = timeoutPref;
       m_autosync_timer.cancel();
@@ -449,15 +442,6 @@ namespace sync {
   void SyncManager::handle_note_saved_or_deleted(const NoteBase::Ptr &)
   {
     if(m_sync_thread == NULL && m_autosync_timeout_pref_minutes > 0) {
-      Glib::TimeSpan time_since_last_check(Glib::DateTime::create_now_utc().difference(m_last_background_check));
-      Glib::TimeSpan time_until_next_check = sharp::time_span(0, m_current_autosync_timeout_minutes, 0) - time_since_last_check;
-      if(sharp::time_span_total_minutes(time_until_next_check) < 1) {
-        DBG_OUT("Note saved or deleted within a minute of next autosync...resetting sync timer");
-        m_current_autosync_timeout_minutes = 1;
-        m_autosync_timer.reset(m_current_autosync_timeout_minutes * 60000);
-      }
-    }
-    else if(m_sync_thread == NULL && m_autosync_timeout_pref_minutes > 0) {
       DBG_OUT("Note saved or deleted...restarting sync timer");
       m_last_background_check = Glib::DateTime::create_now_utc();
       // Perform a sync one minute after setting change
@@ -546,8 +530,7 @@ namespace sync {
   {
     SyncServiceAddin *addin = NULL;
 
-    Glib::ustring sync_service_id = m_gnote.preferences()
-      .get_schema_settings(Preferences::SCHEMA_SYNC)->get_string(Preferences::SYNC_SELECTED_SERVICE_ADDIN);
+    Glib::ustring sync_service_id = m_gnote.preferences().sync_selected_service_addin();
     if(sync_service_id != "") {
       addin = get_sync_service_addin(sync_service_id);
     }
