@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2018 Aurimas Cernius
+ * Copyright (C) 2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 
 
 #include <glibmm/init.h>
+#include <glibmm/main.h>
+#include <glibmm/thread.h>
+#include <giomm/init.h>
+
 #include <UnitTest++/UnitTest++.h>
 
 int main(int /*argc*/, char ** /*argv*/)
@@ -26,7 +30,16 @@ int main(int /*argc*/, char ** /*argv*/)
   // force certain timezone so that time tests work
   setenv("TZ", "Europe/London", 1);
   Glib::init();
+  Gio::init();
 
-  return UnitTest::RunAllTests();
+  auto main_loop = Glib::MainLoop::create();
+  int ret = 0;
+  auto thread = Glib::Thread::create([&main_loop, &ret]() {
+    ret = UnitTest::RunAllTests();
+    main_loop->quit();
+  });
+  main_loop->run();
+  thread->join();
+  return ret;
 }
 
